@@ -64,7 +64,7 @@ class DigitalProductShare(ExtensibleModel):
     )
     share_id = models.CharField(max_length=255, verbose_name=_("Share ID"))
     share_url = models.URLField(verbose_name=_("Share URL"))
-    share_expiration = models.DateField(verbose_name=_("Share expiration"))
+    share_expiration = models.DateTimeField(verbose_name=_("Share expiration"))
 
     def __str__(self):
         return self.share_id
@@ -102,7 +102,7 @@ class DigitalProduct(ExtensibleModel):
         share_url = xml.find("data").find("url").text
         share_expiration = datetime.strptime(
             xml.find("data").find("expiration").text, "%Y-%m-%d %H:%M:%S"
-        ).date()
+        )
 
         return DigitalProductShare.objects.create(
             order_item=order_item,
@@ -490,7 +490,7 @@ class OrderItem(ExtensibleModel):
     @property
     def current_shares(self):
         if self.item.digital_product_object:
-            return self.shares.filter(share_expiration__gte=timezone.now().date())
+            return self.shares.filter(share_expiration__gte=timezone.now())
         return self.shares.none()
 
     @property
