@@ -24,19 +24,19 @@ def has_any_digital_product(user, obj):
 manage_orders_of_form_predicate = has_person & (
     has_global_perm("order.manage_orders") | has_object_perm("order.manage_orders_of_form")
 )
-rules.add_perm("order.manage_orders_of_form", manage_orders_of_form_predicate)
+rules.add_perm("order.manage_orders_of_form_rule", manage_orders_of_form_predicate)
 
 view_orders_predicate = has_person & (
     has_global_perm("order.manage.orders")
     | has_any_object("order.manage_orders_of_form", OrderForm)
 )
-rules.add_perm("order.view_orders", view_orders_predicate)
+rules.add_perm("order.view_orders_rule", view_orders_predicate)
 
 manage_order_predicate = has_person & (has_global_perm("order.manage_orders") | has_order_perm)
-rules.add_perm("order.manage_order", manage_order_predicate)
+rules.add_perm("order.manage_order_rule", manage_order_predicate)
 
 view_my_digital_products_predicate = has_person & (has_any_digital_product)
-rules.add_perm("order.view_my_digital_products", view_my_digital_products_predicate)
+rules.add_perm("order.view_my_digital_products_rule", view_my_digital_products_predicate)
 
-show_menu_predicate = view_orders_predicate | view_my_digital_products_predicate
-rules.add_perm("order.show_menu", show_menu_predicate)
+view_menu_predicate = view_orders_predicate | view_my_digital_products_predicate
+rules.add_perm("order.view_menu_rule", view_menu_predicate)
