@@ -1,4 +1,5 @@
 from django.urls import path
+from django.views.generic import TemplateView
 
 from . import views
 
@@ -7,11 +8,16 @@ urlpatterns = [
     path("list/<int:pk>/", views.OrderDetailView.as_view(), name="show_order"),
     path("list/<int:pk>/edit/", views.OrderEditView.as_view(), name="edit_order"),
     path("list/<int:pk>/delete/", views.OrderDeleteView.as_view(), name="delete_order"),
-    path("<int:pk>/", views.OrderFormView.as_view(), name="order_form"),
     path("confirm/<str:key>/", views.OrderConfirmView.as_view(), name="confirm_order"),
-    path("digital_products/", views.DigitalProductsView.as_view(), name="digital_products"),
     path(
-        "digital_products/<str:key>/", views.DigitalProductsView.as_view(), name="digital_products"
+        "digital_products/",
+        TemplateView.as_view(template_name="core/empty.html"),
+        name="digital_products",
+    ),
+    path(
+        "digital_products/<str:key>/",
+        TemplateView.as_view(template_name="core/empty.html"),
+        name="digital_products",
     ),
     path("pick_up/", views.OrderPickUpFormView.as_view(), name="pick_up_order"),
 ]
